Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(159)

Unified Diff: runtime/vm/code_descriptors.h

Issue 10830131: Adding deopt info to code object. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/code_descriptors.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/code_descriptors.h
===================================================================
--- runtime/vm/code_descriptors.h (revision 10182)
+++ runtime/vm/code_descriptors.h (working copy)
@@ -18,7 +18,7 @@
PcDescriptors::Kind kind; // Descriptor kind (kDeopt, kOther).
intptr_t node_id; // AST node id.
intptr_t token_index; // Token position in source of PC.
- intptr_t try_index; // Try block index of PC.
+ intptr_t try_index; // Try block index of PC or deopt array index.
};
explicit DescriptorList(intptr_t initial_capacity) : list_(initial_capacity) {
@@ -50,6 +50,10 @@
intptr_t node_id,
intptr_t token_index,
intptr_t try_index);
+ void AddDeoptInfo(intptr_t pc_offset,
+ intptr_t node_id,
+ intptr_t token_index,
+ intptr_t deopt_array_index);
RawPcDescriptors* FinalizePcDescriptors(uword entry_point);
« no previous file with comments | « no previous file | runtime/vm/code_descriptors.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698